-----------------------------------------------------------------------------
--
-- data
--   \deaths
--     \<deathName>
--       - count
--       \deathTimes (Array)
--
-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AssessmentDeaths")
L:RegisterTranslations("enUS", function() return {
	["Dead List"] = true,
} end)

-----------------------------------------------------------------------------

local AssessmentDeaths = Assessment:NewModule("Deaths", "AceEvent-2.0", "Parser-3.0")
AssessmentDeaths.db = Assessment:AcquireDBNamespace("Deaths")
Assessment:RegisterDefaults("Deaths", "profile", {
	enable = true
})

-----------------------------------------------------------------------------

Assessment.TagData.deaths =
{
	method = function(data)
				local fightData = data.fightData
				if not fightData then return 0 end
				
				local deaths = fightData.deaths
				if not deaths then return 0 end
				
				if not deaths[data.key] then return 0 end
				return deaths[data.key].count
			 end,
	data = "deaths",
	guaranteeResult = true,
	numeric = true,
}

-----------------------------------------------------------------------------

Assessment.ListType.DeadList =
{
	method = function(fightData)
				if not fightData.deaths then return function() return nil end, nil, nil end
				return pairs(fightData.deaths)
			 end,
	data = "deaths",
	description = L["Dead List"],
}

-----------------------------------------------------------------------------

Assessment.DefaultDisplaySets["Deaths"] =
{
	titleTag		= "Deaths",
	listType		= "GroupMembers", 
	barValueTag		= "deaths", 
	filterType		= "NONZERO",
	fightIndex		= 0,
	barValueTextTag	= "[barValue]",
}

-----------------------------------------------------------------------------

function AssessmentDeaths:OnInitialize()
end

function AssessmentDeaths:OnEnable()
	self:RegisterParserEvent({ eventType = "Death" }, "OnParserDeathEvent")
end

function AssessmentDeaths:OnDisable()
end

-----------------------------------------------------------------------------

function AssessmentDeaths:OnParserDeathEvent(eventData)
	-- Ignore the slain messages.. to avoid double booking
	if eventData.sourceName then return end

	for data in self:IterateUpdateDataTables() do
		data.dataUpdateTimes.deaths = GetTime()
		local deaths = data.deaths
		if not deaths then
			deaths = self:NewTable()
			data.deaths = deaths
		end

		local recipientDeath = deaths[eventData.recipientName]
		if recipientDeath then
			recipientDeath.count = recipientDeath.count + 1
		else
			recipientDeath = self:NewTable()
			recipientDeath.count = 1
			recipientDeath.deathTimes = self:NewTable()
			deaths[eventData.recipientName] = recipientDeath
		end
		table.insert(recipientDeath.deathTimes, GetTime())
	end
end

-----------------------------------------------------------------------------
